Description Usage Arguments Details Value See Also
View source: R/trial_survey_likert.R
Create a Likert question
1 |
prompt |
the prompt for the question |
labels |
the labels on the Likert scale |
required |
is a response to the question required? |
name |
a convenient label for the question |
The question_likert() function is designed to be called when
using trial_survey_likert() to construct a survey page that contains
Likert scale response items. When rendered as part of the study, the text specified
by the prompt argument is shown to the participant, with a set of ordered
categories displayed along a horizontal line. The labels for these categories
are shown beneath the line, and the participant responds by selecting a radio button
that is placed along the line. If required = TRUE the participant will not
be allowed to continue to the next trial unless an answer is provided.
The name argument should be a string that provides a convenient
label for the question. If left unspecified, jsPsych defaults to labelling
the questions within a survey page as "Q0", "Q1", "Q2", etc.
A question object to be passed to trial_survey_likert().
Survey page trials are constructed using the trial_survey_text,
trial_survey_likert, trial_survey_multi_choice and
trial_survey_multi_select functions. Individual questions for survey
trials can be specified using question_text,
question_likert and question_multi.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.