Description Usage Details See Also
Response is accepted with any key press
1 |
Many of the functions within the trial_ family are designed
to allow participants to respond using a key press, generally by specifying a
a choices argument that indicates which keys will be accepted as valid
responses (e.g., choices = c("f","j")). There are also cases where
you may wish to allow every key to be a valid response (e.g., in situations
where "Press any key to continue" is a sensible prompt).
In those cases, specifying choices = respond_any_key() will
produce the desired behaviour.
respond_no_key, trial_html_keyboard_response,
trial_image_keyboard_response, trial_audio_keyboard_response,
trial_video_keyboard_response
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.